@@ -1,14 +1,20 @@
 #'@title Difference of Two Means and Area Under the Curve
 #'
-#'@description Welch's \code{\link[stats:t.test]{t-test}} results
-#'  including Cohen's d with confidence interval (CI),
+#'@description Welch's \code{\link[stats:t.test]{t-test}} results including
+#'  Cohen's d with confidence interval (CI),
 #'  \code{\link[BayesFactor:ttestBF]{Bayes factor}} (BF), and
 #'  \code{\link[pROC:auc]{area under the receiver operating characteristic
-#'  curve}} (AUC).
+#'  curve}} (AUC). For non-parametric version,
+#'  \code{\link[stats:wilcox.test]{Wilcoxon test}} results (Mann–Whitney U test,
+#'  aka "Wilcoxon rank-sum test", for independent samples; Wilcoxon signed-rank
+#'  test for paired samples; along with corresponding rank-based BFs as per van
+#'  Doorn et al., 2020).
 #'@param var1 Numeric vector; numbers of the first variable.
 #'@param var2 Numeric vector; numbers of the second variable.
 #'@param pair Logical. If \code{TRUE}, all tests (t, BF, AUC) are conducted for
 #'  paired samples. If \code{FALSE} (default) for independent samples.
+#'@param nonparametric Logical (\code{FALSE} by default). If \code{TRUE}, uses
+#'  nonparametric (rank-based, "Wilcoxon") t-tests (including BFs; see Details).
 #'@param greater \code{NULL} or string (or number); optionally specifies
 #'  one-sided tests (t and BF): either "1" (\code{var1} mean expected to be
 #'  greater than \code{var2} mean) or "2" (\code{var2} mean expected to be
@@ -17,6 +23,11 @@
 #'@param ci Numeric; confidence level for returned CIs for Cohen's d and AUC.
 #'@param bf_added Logical. If \code{TRUE} (default), Bayes factor is calculated
 #'  and displayed.
+#'@param bf_rscale The scale of the prior distribution (\code{0.707} by
+#'  default).
+#'@param bf_sample Number of samples used to estimate Bayes factor (\code{1000}
+#'  by default). More samples (e.g. \code{10000}) take longer time but give more
+#'  stable BF.
 #'@param auc_added Logical. If \code{TRUE}, AUC is calculated and displayed.
 #'  (\code{FALSE} by default.)
 #'@param r_added Logical. If \code{TRUE} (default), Pearson correlation is
@@ -54,13 +65,20 @@
 #'  displayed in the legend.
 #'
 #'@details
-#' The Bayes factor (BF) is always calculated with the default r-scale of
-#' \code{0.707}. BF supporting null hypothesis is denoted as BF01, while that
-#' supporting alternative hypothesis is denoted as BF10. When the BF is smaller
-#' than 1 (i.e., supports null hypothesis), the reciprocal is calculated (hence,
-#' BF10 = BF, but BF01 = 1/BF). When the BF is greater than or equal to 10000,
-#' scientific (exponential) form is reported for readability. (The original full
-#' BF number is available in the returned named vector as \code{bf}.)
+#' The Bayes factor (BF) supporting null hypothesis is denoted as BF01, while
+#' that supporting alternative hypothesis is denoted as BF10. When the BF is
+#' smaller than 1 (i.e., supports null hypothesis), the reciprocal is calculated
+#' (hence, BF10 = BF, but BF01 = 1/BF). When the BF is greater than or equal to
+#' 10000, scientific (exponential) form is reported for readability. (The
+#' original full BF number is available in the returned named vector as
+#' \code{bf}.)
+#'
+# For details about the nonparametric (rank-based, Wilcoxon) Bayes factors, see
+# van Doorn et al. (2020). The source code for the calculation is a contribution
+# by J. van Doorn; the original version is available via https://osf.io/gny35/.
+#'
+#'For simplicity, Cohen's d is reported for nonparametric tests too: you may
+#'however want to consider reporting alternative effect sizes in this case.
 #'
 #'The original \code{\link[pROC:auc]{pROC::auc}} function, by default, always
 #'returns an AUC greater than (or equal to) .5, assuming that the prediction
@@ -118,10 +136,11 @@
 #'\code{\link[pROC:coords]{pROC::coords}} (\code{x = "best"}); both using the
 #'object \code{\link[pROC:roc]{pROC::roc}}.
 #'
-#'@references Delacre, M., Lakens, D., & Leys, C. (2017). Why psychologists
-#'should by default use Welch's t-test instead of Student's t-test.
-#'International Review of Social Psychology, 30(1).
-#'\doi{http://doi.org/10.5334/irsp.82}
+#'@references 
+#'
+#'Delacre, M., Lakens, D., & Leys, C. (2017). Why psychologists should by
+#'default use Welch's t-test instead of Student's t-test. International Review
+#'of Social Psychology, 30(1). \doi{http://doi.org/10.5334/irsp.82}
 #'
 #'Kelley, K. (2007). Methods for the behavioral, educational, and social
 #'sciences: An R package. Behavior Research Methods, 39(4), 979-984.
@@ -132,6 +151,11 @@
 #'compare ROC curves. BMC bioinformatics, 12(1), 77.
 #'\doi{https://doi.org/10.1186/1471-2105-12-77}
 #'
+#'van Doorn, J., Ly, A., Marsman, M., & Wagenmakers, E.-J. (2020). Bayesian
+#'rank-based hypothesis testing for the rank sum test, the signed rank test, and
+#'Spearman’s rho. Journal of Applied Statistics, 1–23.
+#'\doi{https://doi.org/10.1080/02664763.2019.1709053}
+#'
 #' @seealso \code{\link{corr_neat}}, \code{\link{roc_neat}}
 #' @examples
 #' # assign two variables (numeric vectors)
@@ -152,9 +176,12 @@
 t_neat = function(var1,
                   var2,
                   pair = FALSE,
+                  nonparametric = FALSE,
                   greater = NULL,
                   ci = NULL,
                   bf_added = TRUE,
+                  bf_rscale = sqrt(0.5),
+                  bf_sample = 1000,
                   auc_added = FALSE,
                   r_added = TRUE,
                   for_table = FALSE,
@@ -175,9 +202,12 @@ t_neat = function(var1,
             val_arg(var1, c('num'), 0),
             val_arg(var2, c('num'), 0),
             val_arg(pair, c('bool'), 1),
+            val_arg(nonparametric, c('bool'), 1),
             val_arg(greater, c('null', 'char'), 1, c('1', '2')),
             val_arg(ci, c('null', 'num'), 1),
             val_arg(bf_added, c('bool'), 1),
+            val_arg(bf_rscale, c('num'), 1),
+            val_arg(bf_sample, c('num'), 1),
             val_arg(auc_added, c('bool'), 1),
             val_arg(r_added, c('bool'), 1),
             val_arg(for_table, c('bool'), 1),
@@ -226,40 +256,153 @@ t_neat = function(var1,
     descr_2 = paste0(ro(mean(var2), round_descr),
                      "CHAR_PLUSMIN",
                      ro(stats::sd(var2), round_descr))
+    if (bf_added == TRUE &&
+        nonparametric == TRUE) {
+        if (pair == TRUE) {
+            delta_samps = signRankGibbsSampler(
+                var1,
+                var2,
+                progBar = (!hush),
+                nSamples = bf_sample,
+                cauchyPriorParameter = bf_rscale
+            )$deltaSamples
+        } else {
+            delta_samps = rankSumGibbsSampler(
+                var1,
+                var2,
+                progBar = (!hush),
+                nSamples = bf_sample,
+                cauchyPriorParameter = bf_rscale
+            )$deltaSamples
+        }
+        if (hush == FALSE) {
+            cat('', fill = TRUE)
+        }
+    }
     if (pair == TRUE & r_added == TRUE) {
-        cat("Correlation: ")
-        corr_neat(var1, var2, ci = 0.95, bf_added = FALSE, hush = hush)
+        if (nonparametric == TRUE) {
+            cat("Spearman's rank correlation: ")
+            corr_neat(var1,
+                      var2,
+                      nonparametric = TRUE,
+                      ci = 0.95,
+                      bf_added = FALSE,
+                      hush = hush)
+        } else {
+            cat("Pearson correlation: ")
+            corr_neat(var1,
+                      var2,
+                      ci = 0.95,
+                      bf_added = FALSE,
+                      hush = hush)
+        }
     }
     if (greater == "1") {
         if (hush == FALSE) {
             message("One-sided t-test and BF (with 90% CI default)! H1: first is greater than second.")
         }
-        ttest = stats::t.test(var1, var2, paired = pair, alternative = "greater", conf.level = ci)
-        if (bf_added == TRUE) {
-            bf = as.vector(BayesFactor::ttestBF(
+        if (nonparametric == TRUE) {
+            ttest = stats::wilcox.test(
                 var1,
                 var2,
                 paired = pair,
-                nullInterval = c(0, Inf)
-            )[1])
+                alternative = "greater",
+                conf.level = ci,
+                conf.int = TRUE,
+                exact = TRUE
+            )
+        } else {
+            ttest = stats::t.test(
+                var1,
+                var2,
+                paired = pair,
+                alternative = "greater",
+                conf.level = ci
+            )
+        }
+        if (bf_added == TRUE) {
+            if (nonparametric == TRUE) {
+                bf = computeBayesFactorOneZero(delta_samps,
+                                               oneSided = "right",
+                                               priorParameter = bf_rscale)
+            } else {
+                bf = as.vector(BayesFactor::ttestBF(
+                    var1,
+                    var2,
+                    paired = pair,
+                    iterations = bf_sample,
+                    rscale = bf_rscale,
+                    nullInterval = c(0, Inf)
+                )[1])
+            }
         }
     } else if (greater == "2") {
         if (hush == FALSE) {
             message("One-sided t-test and BF (with 90% CI default)! H1: second is greater than first.")
         }
-        ttest = stats::t.test(var1, var2, paired = pair, alternative = "less", conf.level = ci)
-        if (bf_added == TRUE) {
-            bf = as.vector(BayesFactor::ttestBF(
+        if (nonparametric == TRUE) {
+            ttest = stats::wilcox.test(
                 var1,
                 var2,
                 paired = pair,
-                nullInterval = c(0,-Inf)
-            )[1])
+                alternative = "less",
+                conf.level = ci,
+                conf.int = TRUE,
+                exact = TRUE
+            )
+        } else {
+            ttest = stats::t.test(
+                var1,
+                var2,
+                paired = pair,
+                alternative = "less",
+                conf.level = ci
+            )
+        }
+        if (bf_added == TRUE) {
+            if (nonparametric == TRUE) {
+                bf = computeBayesFactorOneZero(delta_samps,
+                                               oneSided = "left",
+                                               priorParameter = bf_rscale)
+            } else {
+                bf = as.vector(BayesFactor::ttestBF(
+                    var1,
+                    var2,
+                    paired = pair,
+                    iterations = bf_sample,
+                    rscale = bf_rscale,
+                    nullInterval = c(0, -Inf)
+                )[1])
+            }
         }
     } else {
-        ttest = stats::t.test(var1, var2, paired = pair, conf.level = ci)
+        if (nonparametric == TRUE) {
+            ttest = stats::wilcox.test(
+                var1,
+                var2,
+                paired = pair,
+                conf.level = ci,
+                conf.int = TRUE,
+                exact = TRUE
+            )
+        } else {
+            ttest = stats::t.test(var1, var2, paired = pair, conf.level = ci)
+        }
         if (bf_added == TRUE) {
-            bf = as.vector(BayesFactor::ttestBF(var1, var2, paired = pair))
+            if (nonparametric == TRUE) {
+                bf = computeBayesFactorOneZero(delta_samps,
+                                               priorParameter = bf_rscale)
+            } else {
+                bf = as.vector(
+                    BayesFactor::ttestBF(
+                        var1,
+                        var2,
+                        paired = pair,
+                        iterations = bf_sample,
+                        rscale = bf_rscale
+                    )
+                )
+            }
         }
     }
     if (bf_added == TRUE) {
@@ -314,6 +457,17 @@ t_neat = function(var1,
         lower = 'CHAR_MINUSCHAR_INF'
     }
     if (hush == FALSE) {
+        if (nonparametric == TRUE) {
+            if (pair == TRUE) {
+                outbegin = "W = "
+            } else {
+                outbegin = "U = "
+            }
+        } else {
+            outbegin = paste0("t(",
+                              df,
+                              ") = ")
+        }
         prnt(
             test_title,
             " MCHAR_PLUSMINSD = ",
@@ -330,9 +484,7 @@ t_neat = function(var1,
             "])"
         )
         out = paste0(
-            "t(",
-            df,
-            ") = ",
+            outbegin,
             ro(t, 2),
             ", p = ",
             ro(pvalue, 3),
